@@ -3,8 +3,8 @@
 
 #include "ggit-enum-types.h"
 
-/* enumerations from "./ggit-types.h" */
-#include "./ggit-types.h"
+/* enumerations from "/home/nacho/checkout/gnome/libgit2-glib/libgit2-glib/ggit-types.h" */
+#include "/home/nacho/checkout/gnome/libgit2-glib/libgit2-glib/ggit-types.h"
 
 GType
 ggit_branch_type_get_type (void)
@@ -112,6 +112,9 @@ ggit_config_level_get_type (void)
 	if (the_type == 0)
 	{
 		static const GEnumValue values[] = {
+			{ GGIT_CONFIG_LEVEL_PROGRAMDATA,
+			  "GGIT_CONFIG_LEVEL_PROGRAMDATA",
+			  "programdata" },
 			{ GGIT_CONFIG_LEVEL_SYSTEM,
 			  "GGIT_CONFIG_LEVEL_SYSTEM",
 			  "system" },
@@ -124,6 +127,9 @@ ggit_config_level_get_type (void)
 			{ GGIT_CONFIG_LEVEL_LOCAL,
 			  "GGIT_CONFIG_LEVEL_LOCAL",
 			  "local" },
+			{ GGIT_CONFIG_LEVEL_APP,
+			  "GGIT_CONFIG_LEVEL_APP",
+			  "app" },
 			{ GGIT_CONFIG_LEVEL_HIGHEST,
 			  "GGIT_CONFIG_LEVEL_HIGHEST",
 			  "highest" },
@@ -541,20 +547,55 @@ ggit_merge_file_flags_get_type (void)
 }
 
 GType
-ggit_merge_tree_flags_get_type (void)
+ggit_merge_flags_get_type (void)
 {
 	static GType the_type = 0;
 	
 	if (the_type == 0)
 	{
 		static const GFlagsValue values[] = {
-			{ GGIT_MERGE_TREE_FIND_RENAMES,
-			  "GGIT_MERGE_TREE_FIND_RENAMES",
-			  "renames" },
+			{ GGIT_MERGE_FIND_RENAMES,
+			  "GGIT_MERGE_FIND_RENAMES",
+			  "find-renames" },
+			{ GGIT_MERGE_FAIL_ON_CONFLICT,
+			  "GGIT_MERGE_FAIL_ON_CONFLICT",
+			  "fail-on-conflict" },
+			{ GGIT_MERGE_SKIP_REUC,
+			  "GGIT_MERGE_SKIP_REUC",
+			  "skip-reuc" },
+			{ GGIT_MERGE_NO_RECURSIVE,
+			  "GGIT_MERGE_NO_RECURSIVE",
+			  "no-recursive" },
 			{ 0, NULL, NULL }
 		};
 		the_type = g_flags_register_static (
-				g_intern_static_string ("GgitMergeTreeFlags"),
+				g_intern_static_string ("GgitMergeFlags"),
+				values);
+	}
+	return the_type;
+}
+
+GType
+ggit_proxy_type_get_type (void)
+{
+	static GType the_type = 0;
+	
+	if (the_type == 0)
+	{
+		static const GEnumValue values[] = {
+			{ GGIT_PROXY_NONE,
+			  "GGIT_PROXY_NONE",
+			  "none" },
+			{ GGIT_PROXY_AUTO,
+			  "GGIT_PROXY_AUTO",
+			  "auto" },
+			{ GGIT_PROXY_SPECIFIED,
+			  "GGIT_PROXY_SPECIFIED",
+			  "specified" },
+			{ 0, NULL, NULL }
+		};
+		the_type = g_enum_register_static (
+				g_intern_static_string ("GgitProxyType"),
 				values);
 	}
 	return the_type;
